@@ -5,7 +5,7 @@ use Mojo::Collection 'c';
 use DBI;
 use Carp qw(croak);
   
-our $VERSION  = '0.04';
+our $VERSION  = '0.05';
 
 sub new {
 	my $class = shift;
@@ -61,7 +61,7 @@ sub add {
 	my $parent_path = undef;
 	if(defined $parent_id && $parent_id){
 		my $get_id = $self->get_id($parent_id);
-		$parent_path = $get_id->{'path'};
+		$parent_path = $get_id->{$column_path};
 	}
 
 	croak "invalid name" if(!$name);
